local mod = ...



-- Job: Sheep -------------------------------------------------------------------------------------
mod:registerAsset({
	DataType = "JOB",
	Id = "JOB_MONASTICLIFE_SHEEP",
	JobName = "JOB_MONASTICLIFE_SHEEP_NAME",
	JobDescription = "JOB_MONASTICLIFE_SHEEP_DESC",
	IsLockedByDefault = true,
	DefaultBehavior = "BEHAVIOR_GATHER",
	UseWorkplaceBehavior = true,
    ProductionDelay = 50, -- default 30
	AssetJobProgression = "DEFAULT_JOB_PROGRESSION",
	CharacterSetup = {
		LeftHandObject = {
			DataType = "HAND_OBJECT",
			Model = "PREFAB_TOOL_SHEPHERD_STICK"
		},
		RightHandObject = {
			DataType = "HAND_OBJECT",
			Model = "PREFAB_TOOL_SHEPHERD_SCISSORS"
		},
		WalkAnimation = "WALKING",
		IdleAnimation = "SHEPHERD",
	},
})

mod:overrideAsset({
    Id = "MONK",
    CompatibleJobList = {
        Action = "APPEND",
        "JOB_MONASTICLIFE_SHEEP",
    },
})

mod:overrideAsset({
    Id = "MONK_PRIOR",
    CompatibleJobList = {
        Action = "APPEND",
        "JOB_MONASTICLIFE_SHEEP",
    },
})



-- Building Function: Sheep --------------------------------------------------------------------------------------------
mod:registerAsset({
    DataType = "BUILDING_FUNCTION_LIVESTOCK_FARM",
    Id = "BUILDING_FUNCTION_MONASTICLIFE_SHEEP",
    Name = "BUILDING_FUNCTION_MONASTICLIFE_SHEEP_NAME",
    IsPrivate = true,
    WorkerCapacity = 1,
    RelatedJob = {
        Job = "JOB_MONASTICLIFE_SHEEP",
        Behavior = "BEHAVIOR_GATHER",
    },
    SpawningLivestock = "PREFAB_LIVESTOCK_SHEEP",
    LivestockSpawningLocation = "Spawn.Sheep",
    SpawnLivestockButtonText = "BUTTON_MONASTICLIFE_SPAWN",
    RemoveLivestockButtonText = "BUTTON_MONASTICLIFE_DESPAWN",
    -- InputInventoryCapacity = {
	-- 	{ Resource = "MILK", Quantity = 1 },
	-- },
    ResourceListNeeded = {
		{ Resource = "WOOL", Quantity = 1 },
	},
    ResourceProduced = {
		{ Resource = "WOOL", Quantity = 2 },
		{ Resource = "RESOURCE_VELLUM", Quantity = 1 },
        { Resource = "RESOURCE_DUNG", Quantity = 1 },
	},
})



-- Building Part: Sheep -------------------------------------------------------------------------------------

-- Assets
mod:registerAssetId("models/Monastery1.fbx/Prefab/Sheep.Part.001", "PREFAB_MONASTICLIFE_SHEEP1" )
mod:registerAssetId("models/Monastery1.fbx/Prefab/Sheep.Part.001.Constr", "PREFAB_MONASTICLIFE_SHEEP1_CONSTR" )

mod:registerPrefabComponent("models/Monastery1.fbx/Prefab/Sheep.Part.001/Hay.003", {DataType = "COMP_GROUNDED"})
mod:registerPrefabComponent("models/Monastery1.fbx/Prefab/Sheep.Part.001/Hay.004", {DataType = "COMP_GROUNDED"})
mod:registerPrefabComponent("models/Monastery1.fbx/Prefab/Sheep.Part.001/Hay.005", {DataType = "COMP_GROUNDED"})
mod:registerPrefabComponent("models/Monastery1.fbx/Prefab/Sheep.Part.001/Hay.006", {DataType = "COMP_GROUNDED"})
mod:registerPrefabComponent("models/Monastery1.fbx/Prefab/Sheep.Part.001/DungHeap.002", {DataType = "COMP_GROUNDED"})

-- -- Building Part
mod:registerAsset({
	DataType = "BUILDING_PART",
	Id = "BUILDING_PART_MONASTICLIFE_SHEEP1",
	Name = "BUILDING_PART_MONASTICLIFE_SHEEP_NAME",
	ConstructorData = {
		DataType = "BUILDING_CONSTRUCTOR_DEFAULT",
		CoreObjectPrefab = "PREFAB_MONASTICLIFE_SHEEP1",
        MiniatureConfig = {
            ClipUnderGround = true,
            GroupHeight = 0,
            CameraPosition = { 0, 0, 0 },
            OrientationOffset = -90,
            CameraPitchOffset = 0.0
        },
	},
    ConstructionVisual = "PREFAB_MONASTICLIFE_SHEEP1_CONSTR",
	BuildingZone = {
        ZoneEntryList = {
            {
                Polygon = polygon.createRectangle( {8.5, 8.5}, {0.0, 0.0} ),
                Type = { DEFAULT = true, NAVIGABLE = true, GRASS_CLEAR = false },
			},
            {
                Polygon = polygon.createRectangle( {4, 4}, {0.0, 0.0} ),
                Type = { DEFAULT = false, NAVIGABLE = true, GRASS_CLEAR = true },
			},
        },
	},
    Cost = {
        BuildRightTaxes = {
            { Resource = "GOLD_COINS", Quantity = 20 }
        },
        UpkeepCost = {
            { Resource = "GOLD_COINS", Quantity = 10 }
        },
        ResourceNeededList = {
            {
                { Resource = "WOOD", Quantity = 10 },
            },
            {
                { Resource = "STONE", Quantity = 20 },
            },
            {
                { Resource = "STONE", Quantity = 10 },
                { Resource = "TOOL", Quantity = 2 },
            },
            {
                { Resource = "PLANK", Quantity = 20 },
            },
        },
    },
	AssetBuildingFunction = "BUILDING_FUNCTION_MONASTICLIFE_SHEEP",
})


